function u=my_int(f,a,x,ua,h)
% my_int - solves the initial value problem u'(x)=f(x), u(a)=ua
%          using the midpoint rule
%
%   Syntax: 
%           u=my_int(f,a,x,ua,h)
%   Arguments: 
%           f   - string containing the name of a function file,  
%                 for example, f='funk'
%           a   - real number, the intial point
%           x   - real number, the final point
%           ua  - real number, the  initial value
%           h   - positive number, the stepsize
%   Returns: 
%           u -  real number, the approximate solution at the point x
%   Description:
%           The program computes an approximate solution of the initial 
%           value problem  u'(x)=f(x), x>a; u(a)=ua, according to  
%           the midpoint rule. 
%           The function, whose name is contained in f, must return
%           the function values y=f(x).  For example, if  f='funk',
%           then the file funk.m must begin with "function y=funk(x)".
%           The program uses constant stepsize h.  
%   Examples: 
%           u=my_int('cos', 0, pi/2, 0, 1e-3) 
%           computes an approximation of sin(pi/2) 
%   See also:
%          
%           

%----------------------------------------------------------------------
%   Bugs:
%
%   Date created: 2000-11-01
%          
%   Author:  Stig Larsson
%          
%
%   Change history:
%
%------------------------------+---------------------------------------+

i=0;
xi=a+i*h;
u=ua;

while ( xi<x )
  u=u+feval(f,xi+h/2)*h;
  i=i+1;
  xi=a+i*h;
end 







