function moleculePlot(atoms, bonds, name)
% moleculePlot - plot a molecule
%   
% 
%   Syntax: 
%           moleculePlot(atoms, bonds, name)
%   Arguments: 
%           atoms   - The atom matrix
%           bonds   - The bonds matrix
%           name    - The molecule name
%   Returns: 
%           
%   Description:
%
%           Plots a 3D image of a molecule.
%           For a descriptions of the matrices atoms and bonds
%           see: moleculeRead
%
%
%   See also:
%

%----------------------------------------------------------------------
%   Bugs:
%
%   Date created: 
%          990910
%   Author:
%          Marten Levenstam
%
%   Change history:
%
%                              +---------------------------------------+ 
%                              |     Matematik Kf/Kb 1999-2000         | 
%                              |     Copyright (c) 1999                | 
%                              |                                       | 
%                              |     Marten Levenstam                  | 
%                              |     Klas Samuelsson                   | 
%                              |     Dep. of Mathematics               | 
%                              |     Chalmers University of Technology | 
%                              |     S-412 96 Gothenburg               | 
%                              |     SWEDEN                            |     
%                              |     martenl@math.chalmers.se          |     
%                              |     klassam@math.chalmers.se          |     
%                              |                                       |     
%------------------------------+---------------------------------------+
   hold off;
%--------------------------------------%
% Make a sphere to represent the atoms.|
% see help sphere for info on this     |
%--------------------------------------%
   [xs, ys, zs] = sphere(20);
%--------------------------------%
% Scale the radius of the sphere |
%--------------------------------%
   xs = 0.3*xs;
   ys = 0.3*ys;
   zs = 0.3*zs;
%---------------------%
% Some useful numbers |
%---------------------%
   numberOfAtoms = size(atoms,1);
   numberOfBonds = size(bonds,1);
%---------------------------------------------------------------%
% The coordinates are in column 3, 4 and 5 in the matrix atoms  |
% Store this info in variables so that it is easier to remember |
%---------------------------------------------------------------%
   x1Pointer = 3;
   x2Pointer = 4;
   x3Pointer = 5;
%-----------------------------%
% Draw a sphere for each atom |
%-----------------------------%
   for i = 1: numberOfAtoms
     surfl(xs+atoms(i, x1Pointer), ...
           ys+atoms(i, x2Pointer), ...
           zs+atoms(i, x3Pointer));hold on
   end
%------------------------------------%
% Draw a line to represent each bond |
%------------------------------------%
   for i = 1: numberOfBonds
     atom1 = bonds(i, 1)
     atom2 = bonds(i, 2)
     line([atoms(atom1, x1Pointer); atoms(atom2, x1Pointer)], ...
	  [atoms(atom1, x2Pointer); atoms(atom2, x2Pointer)], ...
	  [atoms(atom1, x3Pointer); atoms(atom2, x3Pointer)]);
   end
%--------------%
% Draw a title |
%--------------%
   title(name);
%------------------------------------------%
% Make sure all axis have the same scaling |
%------------------------------------------%
   axis 'equal'
%------------------%
% Some nice colors |
%------------------%
   colormap hot


