function moleculeWrite(fileName, name, atoms, bonds)
% moleculeWrite - Writes a mpdb file 
%   
% 
%   Syntax: 
%           moleculeWrite(fileName, name, atoms, bonds))
%   Arguments: 
%           fileName - name of a mpdb file to read
%           name     - The name of the molecule
%           atoms    - Atom information
%           bonds    - The bonds
%   Returns: 
%           No returned arguments
%   Description:
%           Write the information to a mpdb file.
%           The file can later be read by the moleculeRead function.
%           
%           information obtained from a mpdb file.
%
%           name is a text string containing the name of the
%           molecule.
%
%           atoms is a matrix containing information about the atoms
%           in the molecule. Each row has the following structure:
%           
%              { num,  Atomic number, x, y, z},
%
%           where num is a unique number for each atom in the
%           molecule, Atomic number identifies the Atom, x, y and z
%           are the Cartesian coordinates in Angstrom for the atom.
%
%           bonds is a matrix with information about each bond in
%           the molecule. Each row in this matrix looks like:
%          
%             { num1, num2}
%
%           indicating that there is a bond between atoms num1 and
%           num2. 
%
%
%   See also: moleculeRead
%

%----------------------------------------------------------------------
%   Bugs:
%
%   Date created: 
%          990910
%   Author:
%          Marten Levenstam
%
%   Change history:
%
%                              +---------------------------------------+ 
%                              |     Matematik Kf/Kb 1999-2000         | 
%                              |     Copyright (c) 1999                | 
%                              |                                       | 
%                              |     Marten Levenstam                  | 
%                              |     Klas Samuelsson                   | 
%                              |     Dep. of Mathematics               | 
%                              |     Chalmers University of Technology | 
%                              |     S-412 96 Gothenburg               | 
%                              |     SWEDEN                            |     
%                              |     martenl@math.chalmers.se          |     
%                              |                                       |     
%------------------------------+---------------------------------------+

fid = fopen(fileName, 'w');

numberOfAtoms = size(atoms,1);
numberOfBonds = size(bonds,1);

fprintf(fid, '  %s\n', name);
fprintf(fid, '%i\n', numberOfAtoms);
fprintf(fid, '%i\n', numberOfBonds);

fprintf(fid, '%i %i %f %f %f\n', atoms');
fprintf(fid, '%i  %i\n', bonds');

fclose(fid);
