function theNeighbours = moleculeNeighbours(theAtom, atoms, bonds)
% moleculeNeighbours - Gives the neighbouring atoms to theAtom
%   
%   
% 
%   Syntax: 
%           theNeighbours = moleculeNeighbours(theAtom, atoms, bonds)
%   Arguments: 
%           theAtom - The unique id number for an atom in the molecule
%           atoms   - The atom matrix
%           bonds   - The bonds matrix
%   Returns: 
%           theNeighbours - The id of all atoms joined to theAtom
%                           with a bond
%           
%   Description:
%
%           Finds all atoms joined to a specific atom through a
%           bond. For a descriptions of the matrices atoms and bonds
%           see: moleculeRead
%
%
%   See also:
%           moleculeRead
%

%----------------------------------------------------------------------
%   Bugs:
%
%   Date created: 
%          990910
%   Author:
%          Marten Levenstam
%
%   Change history:
%
%                              +---------------------------------------+ 
%                              |     Matematik Kf/Kb 1999-2000         | 
%                              |     Copyright (c) 1999                | 
%                              |                                       | 
%                              |     Marten Levenstam                  | 
%                              |     Klas Samuelsson                   | 
%                              |     Dep. of Mathematics               | 
%                              |     Chalmers University of Technology | 
%                              |     S-412 96 Gothenburg               | 
%                              |     SWEDEN                            |     
%                              |     martenl@math.chalmers.se          |     
%                              |     klassam@math.chalmers.se          |     
%                              |                                       |     
%------------------------------+---------------------------------------+

n = 0;

numberOfBonds = size(bonds,1);

for i = 1: numberOfBonds
  firstAtom  = bonds(i, 1);
  secondAtom = bonds(i, 2);
  
  if theAtom == firstAtom
    n = n + 1;
    theNeighbours(n) = secondAtom;
  elseif theAtom == secondAtom
    n = n + 1;
    theNeighbours(n) = firstAtom;
  end      
end
